@@ -2,7 +2,7 @@ package Template::Reverse::Converter::TT2;
 
 use Any::Moose;
 use namespace::autoclean;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 sub Convert{
     my $self = shift;
     my $parts = shift;
@@ -30,7 +30,7 @@ Template::Reverse::Convert::TT2 - Convert parts to TT2 format simply
 
 =head1 VERSION
 
-version 0.004
+0.0004
 
 =head1 SYNOPSIS
     
