@@ -2,7 +2,7 @@ package Template::Reverse::Splitter::Whitespace;
 use Any::Moose;
 use namespace::autoclean;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 sub Split{
     my $self = shift;
     my $str = shift;
@@ -15,7 +15,7 @@ Template::Reverse::Splitter::Whitespace - Split text by whitespace
 
 =head1 VERSION
 
-version 0.004
+0.0004
 
 =head1 SYNOPSIS
  
